Release Notes — Translate Toolkit 1.11.0 documentation

Translate Toolkit 1.11.0

- Site
  - Features
  - Installation
  - Converters
  - Tools
  - Scripts
  - Use Cases
  - Supported formats
  - Translate Styleguide
  - Documentation
  - Building
  - Testing
  - Contributing
  - Translate Toolkit Developers Guide
  - Making a Translate Toolkit Release
  - Changelog
  - Release Notes
  - History of the Translate Toolkit
  - License
  - API
- Page
  - Release Notes
- « Changelog
- Translate Toolkit 1.11.0 »

# Release Notes

The following are release notes used on PyPI, Sourceforge and mailing lists for Pootle releases.

- 1.11.0
- 1.11.0-rc1
- 1.10.0
- 1.9.0
- 1.8.1